@@ -21,10 +21,9 @@ from keystoneauth1 import exceptions as kc_exceptions
 from neutronclient.common import exceptions as network_exceptions
 from oslo_log import log as logging
 from oslo_utils import timeutils
-import six
-from six.moves import urllib
 import testscenarios
 import testtools
+import urllib
 
 from heat_tempest_plugin.common import exceptions
 from heat_tempest_plugin.common import remote_client
@@ -67,7 +66,7 @@ def isotime(at):
 
 
 def rand_name(name=''):
-    randbits = six.text_type(random.randint(1, 0x7fffffff))
+    randbits = str(random.randint(1, 0x7fffffff))
     if name:
         return name + '-' + randbits
     else:
@@ -109,6 +108,22 @@ def requires_resource_type(resource_type):
     return decorator
 
 
+def requires_service(service):
+    '''Decorator for tests requiring a specific service being available.
+
+    The decorated test will be skipped when a service is not available. This
+    based on the [service_available] options implemented in tempest
+    '''
+    def decorator(test_method):
+        if not getattr(config.CONF.service_available, service, True):
+            skipper = testtools.skip(
+                "%s service not available, skipping test." % service)
+            return skipper(test_method)
+        else:
+            return test_method
+    return decorator
+
+
 def requires_service_type(service_type):
     '''Decorator for tests requiring a specific service being available.
 
@@ -125,7 +140,7 @@ def requires_service_type(service_type):
                 service_type, conf.region, conf.endpoint_type)
         except kc_exceptions.EndpointNotFound:
             skipper = testtools.skip(
-                "%s service not available, skipping test." % service_type)
+                "%s service type not available, skipping test." % service_type)
             return skipper(test_method)
         else:
             return test_method
@@ -153,7 +168,7 @@ def requires_feature(feature):
 
 
 def requires_service_feature(service, feature):
-    '''Decorator for tests requring specific service feature enabled in tempest.
+    '''Decorator for tests requring specific service feature
 
     The decorated test will be skipped when a specific feature is disabled.
     '''
@@ -204,7 +219,7 @@ class HeatIntegrationTest(testtools.testcase.WithAttributes,
         self.setup_clients(self.conf, True)
 
     def get_remote_client(self, server_or_ip, username, private_key=None):
-        if isinstance(server_or_ip, six.string_types):
+        if isinstance(server_or_ip, str):
             ip = server_or_ip
         else:
             network_name_for_ssh = self.conf.network_for_ssh
